==> nextcloud-25.0.6.tgz: nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Adresse ist zu lang",
    "The given web address is not a valid URL" : "Die eingegebene Internet-Adresse ist keine gültige URL",
    "The given legal notice address is too long" : "Die im Impressum angegebene Adresse ist zu lang",
    "The given legal notice address is not a valid URL" : "Die eingegebene Impressums-Adresse ist keine gültige URL",
    "The given privacy policy address is too long" : "Die eingegebene Adresse der Datenschutzbestimmungen ist zu lang",
    "The given privacy policy address is not a valid URL" : "Die eingegebene Adresse der Datenschutzerklärung ist keine gültige URL",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "Disable-user-theming should be true or false" : "Benutzer-Design deaktivieren sollte wahr oder falsch sein",
    "Saved" : "Gespeichert",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer, als die MAX_FILE_SIZE-Vorgabe erlaubt, die im HTML-Formular spezifiziert ist",
    "The file was only partially uploaded" : "Die Datei konnte nur teilweise hochgeladen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "No file uploaded" : "Keine Datei hochgeladen",
    "Failed to clean up the old administration theming images folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
    "Failed to clean up the old administration image folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sie benutzen bereits ein benutzerdefiniertes Design. Die App \"Theming\" würde dies überschreiben.",
    "Theming" : "Design",
    "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
    "Dark theme with high contrast mode" : "Dunkles Design mit hohem Kontrastmodus",
    "Enable dark high contrast mode" : "Kontrastreichen Modus aktivieren",
    "Similar to the high contrast mode, but with dark colours." : "Ähnlich wie der Hochkontrastmodus, aber mit dunklen Farben.",
    "Dark theme" : "Dunkles Design",
    "Enable dark theme" : "Dunkles Design aktivieren",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ein dunkles Design zur Entlastung der Augen durch Verringerung der Gesamtleuchtkraft und -helligkeit.",
    "System default theme" : "Standard-System-Design",
    "Enable the system default" : "Systemstandard aktivieren",
    "Using the default system appearance." : "Das Standard-System-Erscheinungsbild verwenden.",
    "Dyslexia font" : "Legasthenie-Schriftart",
    "Enable dyslexia font" : "Legasthenie-Schriftart aktivieren",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren.",
    "High contrast mode" : "Kontrastreicher Modus",
    "Enable high contrast mode" : "Kontrastreichen Modus aktivieren",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreicher Modus, der die Navigation erleichtert. Die Bildqualität wird reduziert, die Übersichtlichkeit jedoch erhöht.",
    "Light theme" : "Helles Design",
    "Enable the default light theme" : "Helles Standarddesign aktivieren",
    "The default light appearance." : "Das Standard helle Aussehen.",
    "Legal notice" : "Impressum",
    "Privacy policy" : "Datenschutz",
    "Adjust the Nextcloud theme" : "Passe das Design von Nextcloud an",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Das Ändern des Designs ermöglicht es auf einfache Weise, das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Advanced options" : "Erweiterte Optionen",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installieren Sie die ImageMagick PHP-Erweiterung mit Unterstützung für SVG-Bilder, um automatisch Favicons auf Basis des hochgeladenen Logos und der Farbe zu erstellen.",
    "Name" : "Name",
    "Web link" : "Internet-Link",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "Slogan" : "Slogan",
    "Color" : "Farbe",
    "Logo" : "Logo",
    "Upload new logo" : "Neues Logo hochladen",
    "Background and login image" : "Hintergrund und Anmeldebild",
    "Upload new background and login image" : "Ein neues Hintergrund- und Anmeldebild hochladen",
    "Legal notice link" : "Link zum Impressum",
    "Privacy policy link" : "Link zu den Datenschutzbestimmungen",
    "Header logo" : "Kopfbereichs-Logo",
    "Upload new header logo" : "Neues Logo für den Kopfbereich hochladen",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Neues Favicon hochladen",
    "User settings" : "Benutzer-Einstellungen",
    "Disable user theming" : "Benutzer-Design deaktivieren",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Trotz der von Ihnen vorgenommenen Auswahl und Anpassung, können Benutzer ihren Hintergrund und ihre Farben ändern. Wenn Sie Ihre Anpassung erzwingen möchten, können Sie dies hier aktivieren.",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In einigen Fällen können Tastenkombinationen Barrierefreiheits-Tools beeinträchtigen. Damit Sie sich richtig auf Ihr Werkzeug konzentrieren können, können Sie hier alle Tastaturkürzel deaktivieren. Dadurch werden auch alle verfügbaren Verknüpfungen in Apps deaktiviert.",
    "Disable all keyboard shortcuts" : "Alle Tastenkombinationen deaktivieren",
    "Background" : "Hintergrund",
    "Customization has been disabled by your administrator" : "Diese Anpassungsmöglichkeit wurde von Ihrer Administration deaktiviert",
    "Set a custom background" : "Einen benutzerdefinierten Hintergrund setzen",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Der universelle Zugang ist für uns sehr wichtig. Wir halten uns an Webstandards und prüfen, ob alles auch ohne Maus und unterstützende Software wie Screenreader nutzbar ist. Wir streben die Einhaltung der {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 auf AA-Niveau an, mit dem kontrastreichen Design sogar auf AAA-Niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Wenn Sie Fehler finden, melden Sie diese bitte in {issuetracker}unserem Issue Tracker{linkend}. Und wenn Sie mithelfen möchten, treten Sie dem {designteam}Designteam{linkend} bei!",
    "Custom background" : "Benutzerdefinierter Hintergrund",
    "Default background" : "Standardhintergrund",
    "Change color" : "Farbe ändern",
    "No background" : "Kein Hintergrund",
    "Select a background from your files" : "Wählen Sie einen Hintergrund aus Ihren Dateien",
    "Theme selection is enforced" : "Designauswahl wird erzwungen",
    "Select a custom color" : "Eine benutzerdefinierte Farbe auswählen",
    "Reset to default" : " Auf Standard zurücksetzen ",
    "Upload" : "Hochladen",
    "Remove background image" : "Hintergrundbild entfernen",
    "Loading preview…" : "Lade Vorschau…",
    "Admin" : "Administration",
    "Error uploading the file" : "Fehler beim Hochladen der Datei",
    "Name cannot be empty" : "Der Name darf nicht leer sein",
    "Open documentation" : "Dokumentation öffnen",
    "https://…" : "https://…",
    "Login image" : "Anmeldebild",
    "Upload new login background" : "Neuen Anmelde-Hintergrund hochladen",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installieren Sie die Imagemagick PHP-Erweiterung mit Unterstützung für SVG-Bilder, um automatisch Favicons auf Basis des hochgeladenen Logos und der Farbe zu erstellen.",
    "Migrate and clean up admin theming images" : "Admin-Designbilder migrieren und bereinigen",
    "Failed to clean up the old admin theming images folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In einigen Fällen können Tastenkombinationen Barrierefreiheits-Tools beeinträchtigen. Damit Sie sich richtig auf Ihr Werkzeug konzentrieren können, können Sie hier alle Tastaturkürzel deaktivieren. Dadurch werden auch alle verfügbaren Verknüpfungen in Apps deaktiviert.",
    "Pick from Files" : "Aus Dateien auswählen",
    "Default image" : "Standardbild",
    "Custom color" : "Benutzerdefinierte Farbe",
    "Plain background" : "Einfacher Hintergrund",
    "Insert from {productName}" : "Von {productName} einfügen",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Obwohl Sie Ihre Instanz auswählen und anpassen können, können Benutzer ihren Hintergrund und ihre Farben ändern. Wenn Sie Ihre Anpassung erzwingen möchten, können Sie dieses Kontrollkästchen aktivieren."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Adresse ist zu lang",
    "The given web address is not a valid URL" : "Die eingegebene Internet-Adresse ist keine gültige URL",
    "The given legal notice address is too long" : "Die im Impressum angegebene Adresse ist zu lang",
    "The given legal notice address is not a valid URL" : "Die eingegebene Impressums-Adresse ist keine gültige URL",
    "The given privacy policy address is too long" : "Die eingegebene Adresse der Datenschutzbestimmungen ist zu lang",
    "The given privacy policy address is not a valid URL" : "Die eingegebene Adresse der Datenschutzerklärung ist keine gültige URL",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "Disable-user-theming should be true or false" : "Benutzer-Design deaktivieren sollte wahr oder falsch sein",
    "Saved" : "Gespeichert",
    "Invalid app given" : "Ungültige App angegeben",
    "Invalid type for setting \"defaultApp\" given" : "Ungültiger Typ für die Einstellung \"defaultApp“ angegeben",
    "Invalid setting key" : "Ungültiger Einstellungsschlüssel",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer, als die MAX_FILE_SIZE-Vorgabe erlaubt, die im HTML-Formular spezifiziert ist",
    "The file was only partially uploaded" : "Die Datei konnte nur teilweise hochgeladen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "No file uploaded" : "Keine Datei hochgeladen",
    "Failed to clean up the old administration theming images folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
    "Failed to clean up the old administration image folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sie benutzen bereits ein benutzerdefiniertes Design. Die App \"Theming\" würde dies überschreiben.",
    "Theming" : "Design",
    "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
    "PHP Imagick module" : "PHP Imagick-Modul",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Das PHP-Modul \"imagick\" ist nicht aktiviert, die Theming-App hingegen schon. Damit die Favicon-Generierung korrekt funktioniert, müssen Sie dieses Modul installieren und aktivieren.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Das PHP-Modul \"imagick\" in dieser Instanz hat keine SVG-Unterstützung. Für eine bessere Kompatibilität empfiehlt es sich, es zu installieren.",
    "Dark theme with high contrast mode" : "Dunkles Design mit hohem Kontrastmodus",
    "Enable dark high contrast mode" : "Kontrastreichen Modus aktivieren",
    "Similar to the high contrast mode, but with dark colours." : "Ähnlich wie der Hochkontrastmodus, aber mit dunklen Farben.",
    "Dark theme" : "Dunkles Design",
    "Enable dark theme" : "Dunkles Design aktivieren",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ein dunkles Design zur Entlastung der Augen durch Verringerung der Gesamtleuchtkraft und -helligkeit.",
    "System default theme" : "Standard-System-Design",
    "Enable the system default" : "Systemstandard aktivieren",
    "Using the default system appearance." : "Das Standard-System-Erscheinungsbild verwenden.",
    "Dyslexia font" : "Legasthenie-Schriftart",
    "Enable dyslexia font" : "Legasthenie-Schriftart aktivieren",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren.",
    "High contrast mode" : "Kontrastreicher Modus",
    "Enable high contrast mode" : "Kontrastreichen Modus aktivieren",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreicher Modus, der die Navigation erleichtert. Die Bildqualität wird reduziert, die Übersichtlichkeit jedoch erhöht.",
    "Light theme" : "Helles Design",
    "Enable the default light theme" : "Helles Standarddesign aktivieren",
    "The default light appearance." : "Das Standard helle Aussehen.",
    "Legal notice" : "Impressum",
    "Privacy policy" : "Datenschutz",
    "Adjust the Nextcloud theme" : "Passe das Design von Nextcloud an",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Das Ändern des Designs ermöglicht es auf einfache Weise, das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Advanced options" : "Erweiterte Optionen",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installieren Sie die ImageMagick PHP-Erweiterung mit Unterstützung für SVG-Bilder, um automatisch Favicons auf Basis des hochgeladenen Logos und der Farbe zu erstellen.",
    "Name" : "Name",
    "Web link" : "Internet-Link",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "Slogan" : "Slogan",
    "Color" : "Farbe",
    "Logo" : "Logo",
    "Upload new logo" : "Neues Logo hochladen",
    "Background and login image" : "Hintergrund und Anmeldebild",
    "Upload new background and login image" : "Ein neues Hintergrund- und Anmeldebild hochladen",
    "Legal notice link" : "Link zum Impressum",
    "Privacy policy link" : "Link zu den Datenschutzbestimmungen",
    "Header logo" : "Kopfbereichs-Logo",
    "Upload new header logo" : "Neues Logo für den Kopfbereich hochladen",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Neues Favicon hochladen",
    "User settings" : "Benutzer-Einstellungen",
    "Disable user theming" : "Benutzer-Design deaktivieren",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Trotz der von Ihnen vorgenommenen Auswahl und Anpassung, können Benutzer ihren Hintergrund und ihre Farben ändern. Wenn Sie Ihre Anpassung erzwingen möchten, können Sie dies hier aktivieren.",
    "Appearance and accessibility settings" : "Aussehen- und Barrierefreiheitseinstellungen",
    "Background" : "Hintergrund",
    "Customization has been disabled by your administrator" : "Diese Anpassungsmöglichkeit wurde von Ihrer Administration deaktiviert",
    "Set a custom background" : "Einen benutzerdefinierten Hintergrund setzen",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In einigen Fällen können Tastenkombinationen Barrierefreiheits-Tools beeinträchtigen. Damit Sie sich richtig auf Ihr Werkzeug konzentrieren können, können Sie hier alle Tastaturkürzel deaktivieren. Dadurch werden auch alle verfügbaren Verknüpfungen in Apps deaktiviert.",
    "Disable all keyboard shortcuts" : "Alle Tastenkombinationen deaktivieren",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Der universelle Zugang ist für uns sehr wichtig. Wir halten uns an Webstandards und prüfen, ob alles auch ohne Maus und unterstützende Software wie Screenreader nutzbar ist. Wir streben die Einhaltung der {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 auf AA-Niveau an, mit dem kontrastreichen Design sogar auf AAA-Niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Wenn Sie Fehler finden, melden Sie diese bitte in {issuetracker}unserem Issue Tracker{linkend}. Und wenn Sie mithelfen möchten, treten Sie dem {designteam}Designteam{linkend} bei!",
    "Current selected app: {app}, position {position} of {total}" : "Aktuell ausgewählte App: {app}, Position {position} von {total}",
    "Move up" : "Nach oben verschieben",
    "Move down" : "Nach unten verschieben",
    "Custom background" : "Benutzerdefinierter Hintergrund",
    "Default background" : "Standardhintergrund",
    "Change color" : "Farbe ändern",
    "No background" : "Kein Hintergrund",
    "Select a background from your files" : "Wählen Sie einen Hintergrund aus Ihren Dateien",
    "Select background" : "Hintergrund wählen",
    "No background has been selected" : "Es wurde kein Hintergrund ausgewählt",
    "Theme selection is enforced" : "Designauswahl wird erzwungen",
    "Navigation bar settings" : "Einstellungen der Navigationsleiste",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Sie können die App-Reihenfolge für die Navigationsleiste konfigurieren. Der erste Eintrag ist die Standard-App, die nach der Anmeldung oder beim Klicken auf das Logo geöffnet wird.",
    "The default app can not be changed because it was configured by the administrator." : "Die Standard-App kann nicht geändert werden, da sie von der Administration konfiguriert wurde.",
    "The app order was changed, to see it in action you have to reload the page." : "Die App-Reihenfolge wurde geändert. Um die Änderungen zu sehen, müssen Sie die Seite neu laden.",
    "Reset default app order" : "Standard App-Reihenfolge zurücksetzen",
    "Could not set the app order" : "Die App-Reihenfolge konnte nicht festgelegt werden",
    "Could not reset the app order" : "Standard App-Reihenfolge konnte nicht zurückgesetzt werden",
    "Default app" : "Standard-App",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Die Standard-App ist die App, die z. B. nach der Anmeldung oder nach Klicken auf das Logo im Menü geöffnet wird.",
    "Use custom default app" : "Benutzerdefinierte Standard-App verwenden",
    "Global default app" : "Globale Standard-App",
    "Global default apps" : "Globale Standard-Apps",
    "Default app priority" : "Standard-App-Priorität",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Wenn eine App für einen Benutzer nicht aktiviert ist, wird die nächste App mit niedrigerer Priorität verwendet.",
    "Could not set global default apps" : "Globale Standard-Apps konnten nicht festgelegt werden",
    "Select a custom color" : "Eine benutzerdefinierte Farbe auswählen",
    "Reset to default" : " Auf Standard zurücksetzen ",
    "Upload" : "Hochladen",
    "Remove background image" : "Hintergrundbild entfernen"
},
"nplurals=2; plural=(n != 1);");
